package com.muyu.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.EngineVersion;
import com.muyu.req.EngineVersionQueryReq;
import com.muyu.service.EngineVersionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author：qdm
 * @Package：com.muyu.controller
 * @Project：cloud-etl-engine
 * @name：EngineVersionController
 * @Date：2024/8/22 21:59
 */
@RestController
@RequestMapping("/version")
public class EngineVersionController {

    @Autowired
    EngineVersionService engineVersionService;

    /**
     * 查询引擎规则配置列表
     */
    @RequiresPermissions("rule-engine:version:list")
    @GetMapping("/list")
    public Result<List<EngineVersion>> list(EngineVersionQueryReq engineConfigQueryReq) {
        return Result.success(engineVersionService.list(EngineVersion.queryBuild(engineConfigQueryReq)));
    }

    @PostMapping("/insert")
    public Result<EngineVersion> insert(EngineVersion engineVersion) {
        EngineVersion add = engineVersionService.add(engineVersion);
        return Result.success(add);
    }

    @PostMapping("/update")
    public Result<EngineVersion> update(EngineVersion engineVersion) {
        EngineVersion update = engineVersionService.updateMsg(engineVersion);
        return Result.success(update);
    }

    @PostMapping("/delete/{id}")
    public Result delete(@PathVariable Long id) {
        boolean b = engineVersionService.removeById(id);
        return Result.success(b);
    }
}
