package com.muyu.service.serviceImpl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.domain.EngineVersion;
import com.muyu.mapper.EngineVersionMapper;
import com.muyu.service.EngineVersionService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author：qdm
 * @Package：com.muyu.service.serviceImpl
 * @Project：cloud-etl-engine
 * @name：EngineVersionServiceImpl
 * @Date：2024/8/22 22:17
 */
@Service
public class EngineVersionServiceImpl extends ServiceImpl<EngineVersionMapper, EngineVersion> implements EngineVersionService {


    @Override
    public List<EngineVersion> list(EngineVersion engineConfig) {
        LambdaQueryWrapper<EngineVersion> queryWrapper = new LambdaQueryWrapper<>();

        if (StringUtils.isNotNull(engineConfig.getVersionCode())) {
            queryWrapper.eq(EngineVersion::getVersionCode, engineConfig.getVersionCode());
        }

        if (StringUtils.isNotNull(engineConfig.getRuleContent())) {
            queryWrapper.eq(EngineVersion::getRuleContent, engineConfig.getRuleContent());
        }

        if (StringUtils.isNotNull(engineConfig.getEngineMaintenanceId())) {
            queryWrapper.eq(EngineVersion::getEngineMaintenanceId, engineConfig.getEngineMaintenanceId());
        }

        return list(queryWrapper);
    }

    @Override
    public EngineVersion add(EngineVersion engineVersion) {
        if (save(engineVersion)) {
            return engineVersion;
        }
        return null;
    }

    @Override
    public EngineVersion updateMsg(EngineVersion engineVersion) {
        if (updateById(engineVersion)) {
            return engineVersion;
        }
        return null;
    }

}
